<?
	require('./include/conf.php.inc');
	require('./include/index.php.inc');
?>
<?='<?xml version="1.0" encoding="ISO-8859-15"?>'?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="nl">
	<head>
		<title>http://<?=$_SERVER["SERVER_NAME"] . $_SERVER["REQUEST_URI"]?></title>
		<meta name="Author" content="Micha&euml;l Hompus" />
		<meta name="date" content="2003-02-02T00:00:00+01:00" />
		<link rel="stylesheet" type="text/css" href="<?=$XPIndexDir?>/css/index.php">
	</head>
	<body>
		<table cellspacing="0" cellpadding="0">
			<thead>
				<tr>
					<th class="left"><?=$captions['filename'][$XPIndexLanguage]?></th>
					<th class="right"><?=$captions['size'][$XPIndexLanguage]?></th>
					<th class="left"><?=$captions['type'][$XPIndexLanguage]?></th>
					<th class="left"><?=$captions['changed'][$XPIndexLanguage]?></th>
					<th class="left"><?=$captions['owner'][$XPIndexLanguage]?></th>
					<th class="left"><?=$captions['group'][$XPIndexLanguage]?></th>
					<th class="left"><?=$captions['attributes'][$XPIndexLanguage]?></th>
					<th class="fill">&nbsp;</th>
				</tr>
			</thead>
			<tbody>
<?ParseDir($_SERVER["DOCUMENT_ROOT"], $_SERVER["REQUEST_URI"]);?>
			</tbody>
		</table>
	</body>
</html>
