<?
	require('../include/conf.php.inc');

	$mod_gmt = gmdate('D, d M Y H:i:s', $mtime) . ' GMT';
	header('Last-Modified: ' . $mod_gmt);
	header('Cache-Control: public, max-age=86400');
	header('Content-type: text/css');
?>
a {
	text-decoration: none;
	color: #000000;
	background-color: transparent;
	padding-left: 3px;
	padding-right: 3px;
	padding-top: 1px;
	padding-bottom: 1px;
}

a.icon:hover {
	background-color: transparent;
	color: #000000;
}

a:hover {
	background-color: #B2B4BF;
	color: #000000;
}

body {
	background-color: #FFFFFF;
	color: #000000;
	padding: 0px;
	margin: 0px;
}

img {
	width: 16px;
	height: 16px;
	border-style: none;
	border-width: 0px;
	vertical-align: bottom;
	margin-left: 2px;
}

table {
	width: 100%;
}

td {
	font-family: Tahoma, Verdana, Arial, sans-serif;
	font-size: 8pt;
	font-weight: normal;
	padding-top: 2px;
	padding-right: 7px;
	height: 18px;
	white-space: nowrap;
	width: 5%;
}

td.groupheader {
	font-weight: bold;
	background-image: url("<?=$XPIndexDir?>/images/group.png");
	background-repeat: no-repeat;
	background-position: left bottom;
	padding-left: 14px;
	padding-top: 3px;
	padding-bottom: 2px;
}

th {
	font-family: Tahoma, Verdana, Arial, sans-serif;
	font-size: 8pt;
	font-weight: normal;
	background-color: transparent;
	padding-top: 3px;
	padding-bottom: 4px;
	padding-left: 5px;
	padding-right: 5px;
	background-image: url("<?=$XPIndexDir?>/images/head.png");
	background-repeat: repeat-x;
	background-position: right;
	white-space: nowrap;
}

th.fill {
	background-image: url("<?=$XPIndexDir?>/images/headback.png");
	background-repeat: repeat-x;
}

thead {
	position: fixed;
}

.left {
	text-align: left;
}

.right {
	text-align: right;
}
