<?php

// XP Index Directory:
// Relative position to the webroot
$XPIndexDir = '/XPindex';

// UserDirs:
// The directory where the userdirs are created (default: /home).
$UserDirs = '/home';

// ApacheUserDir:
// This is the same entry as can be found in the apache config file (default: public_html).
$ApacheUserDir = 'public_html';

// XP Index Language:
// 0 = Dutch
// 1 = English
$XPIndexLanguage = 0;

// File descriptions:
$knownfiletypes = Array(
//	'Extention'	=> Array('Dutch',								'English'),
	'000000000'	=> Array('Bovenliggende map', 					'Parent folder'),
	'000000001'	=> Array('Map',									'Folder'),
	'bmp'		=> Array('Bitmapafbeelding',					'Bitmap Image'),
	'css'		=> Array('Document met trapgewijs opmaakmodel',	'CSS File'),
	'db'		=> Array('Databasebestand',						'DBase File'),
	'dll'		=> Array('Toepassingsuitbreiding',				'Application Extension'),
	'doc'		=> Array('Microsoft Word-document',				'Microsoft Word-document'),
	'exe'		=> Array('Toepassing',							'Application'),
	'gif'		=> Array('GIF-afbeelding',						'GIF Image'),
	'gz'		=> Array('GZip-archief',						'GZip Archive'),
	'htm'		=> Array('HTML-document',						'HTML Document'),
	'html'		=> Array('HTML-document',						'HTML Document'),
	'ini'		=> Array('Configuratie-instellingen',			'Configuratie Settings'),
	'jpg'		=> Array('JPEG-afbeelding',						'JPEG Image'),
	'jpeg'		=> Array('JPEG-afbeelding',						'JPEG Image'),
	'js'		=> Array('JScript Script-bestand',				'JScript Script File'),
	'jse'		=> Array('JScript Encoded Script-bestand',		'JScript Encoded Script File'),
	'mp3'		=> Array('MP3 media-bestand',					'MP3 Media File'),
	'pdf'		=> Array('Adobe Acrobat Document',				'Adobe Acrobat Document'),
	'php'		=> Array('PHP Script-bestand',					'PHP Script File'),
	'php3'		=> Array('PHP3 Script-bestand',					'PHP3 Script File'),
	'php4'		=> Array('PHP4 Script-bestand',					'PHP4 Script File'),
	'phps'		=> Array('PHP Script Source-bestand',			'PHP Script Source File'),
	'phtml'		=> Array('PHP Script-bestand',					'PHP Script File'),
	'png'		=> Array('PNG-afbeelding',						'PNG Image'),
	'rar'		=> Array('WinRAR-archief',						'WinRAR Archive'),
	'sql'		=> Array('SQL Script-bestand',					'SQL Script File'),
	'tar'		=> Array('Tarball-archief',						'Tarball Archive'),
	'tgz'		=> Array('GZip Tarball-archief',				'GZip Tarball Archive'),
	'txt'		=> Array('Tekstdocument',						'TXT File'),
	'xls'		=> Array('Microsoft Excel-werkblad', 			'Microsoft Excel-sheet'),
	'xml'		=> Array('XML-document', 						'XML Document'),
	'xsl'		=> Array('XSL-opmaakmodel',			 			'XSL Document'),
	'xslt'		=> Array('XSL Transformation', 					'XSL Transformation'),
	'zip'		=> Array('Gecomprimeerde map',					'Compressed folder')
);

//	File icons:
$icons = Array(
	'000000000'	=> 'mapup.png',
	'000000001'	=> 'map.png',
	'bmp'		=> 'bmp.png',
	'css'		=> 'ini.png',
	'db'		=> 'dll.png',
	'dll'		=> 'dll.png',
	'gz'		=> 'zip.png',
	'gif'		=> 'gif.png',
	'html'		=> 'html.png',
	'htm'		=> 'html.png',
	'ini'		=> 'ini.png',
	'jpg'		=> 'jpg.png',
	'jpeg'		=> 'jpg.png',
	'js'		=> 'js.png',
	'jse'		=> 'js.png',
	'pdf'		=> 'pdf.png',
	'php'		=> 'php.png',
	'php3'		=> 'php.png',
	'php4'		=> 'php.png',
	'phps'		=> 'php.png',
	'phtml'		=> 'php.png',
	'png'		=> 'gif.png',
	'rar'		=> 'rar.png',
	'shtm'		=> 'html.png',
	'shtml'		=> 'html.png',
	'sql'		=> 'sql.png',
	'tar'		=> 'zip.png',
	'tgz'		=> 'zip.png',
	'txt'		=> 'txt.png',
	'xls'		=> 'xls.png',
	'xml'		=> 'xml.png',
	'xsl'		=> 'xsl.png',
	'xslt'		=> 'xslt.png',
	'zip'		=> 'zip.png'
);

$captions = Array(
//	'index'			=> Array('Dutch',			'English'),
	'file'			=> Array('bestand',			'file'),
	'filename'		=> Array('Naam',			'Filename'),
	'size'			=> Array('Grootte',			'Size'),
	'type'			=> Array('Type',			'Type'),
	'changed'		=> Array('Gewijzigd op',	'Changed at'),
	'owner'			=> Array('Eigenaar',		'Owner'),
	'group'			=> Array('Groep',			'Group'),
	'attributes'	=> Array('Kenmerken',		'Attributes'),
	'changed'		=> Array('Gewijzigd op',	'Changed at')
);
?>